@@ -1,4 +1,4 @@
-from django.core.checks import Warning, register
+from django.core.checks import Info, register
 
 from leukeleu_django_gdpr.gdpr import get_pii_stats
 
@@ -7,10 +7,10 @@ class Tags:
     confidentiality = "confidentiality"
 
 
-W001 = Warning(
+I001 = Info(
     "You have one or more model field(s) without a PII classification.",
     hint="Update gpdr.yml and mark all field with either pii: true or pii: false.",
-    id="gdpr.W001",
+    id="gdpr.I001",
 )
 
 
@@ -22,6 +22,6 @@ def check_pii_stats(app_configs, **kwargs):
     stats = get_pii_stats()
 
     if stats[None] > 0:
-        return [W001]
+        return [I001]
     else:
         return []
